<?php
// $Id: innovationnewsprofile.profile,v 1.1.2.25 2010/07/11 00:22:59 JohnKarahalis Exp $

/**
 * Implementation of hook_profile_details().
 */
function innovationnewsprofile_profile_details() {
  $description = st('The Innovation News profile creates a cross-media  ' .
                    'newspaper. If you do not wish to utilize the ' .
                    'cross-media tools, the site it creates can be used as ' .
                    'simply a news website.');

  return array(
    'name' => 'Innovation News',
    'description' => $description,
  );

}

/**
 * Implementation of hook_profile_modules().
 */
function innovationnewsprofile_profile_modules() {
  $modules = array(
    // Core - required.
    'block',
    'filter',
    'node',
    'system',
    'user',

    // Core - optional.
    'dblog',
    'help',
    'menu',
    'search',
    'taxonomy',
    'trigger',
    'update',
    'path',
    'php',

    // Innovation News modules.
    'innovationnews',
    'editnews',
    'editionmanager',
    'editionviewer',
    'xmltokml',

    // Other contributed modules.
    'contemplate',
    'image',
    'image_attach',
    'image_gallery',
    'install_profile_api',
    'token',
    'pathauto',
    'captcha',
    'views',
    'views_ui',

    // CCK modules.
    'content',
    'content_permissions',
    'number',
    'text',
    'optionwidgets'
  );

  return $modules;
}

/**
 * Implementation of hook_profile_tasks().
 */
function innovationnewsprofile_profile_tasks(&$task, $url) {
  // Enable the Install Profile API.
  install_include(innovationnewsprofile_profile_modules());

  _innovationnewsprofile_set_content_types();
  _innovationnewsprofile_set_vocabularies();
  _innovationnewsprofile_set_views();
  _innovationnewsprofile_modify_settings();
  _innovationnewsprofile_modify_blocks();
  _innovationnewsprofile_set_cck_fields();
  _innovationnewsprofile_save_nodes();
  _innovationnewsprofile_modify_menus();
  _innovationnewsprofile_set_permissions();
}

/**
 * Modify the default settings of Drupal and contributed modules.
 */
function _innovationnewsprofile_modify_settings() {
  // Basic Drupal settings.
  variable_set('site_frontpage', 'home');
  variable_set('user_register', 0);

  // Set Toasted as the default theme and the admin theme.
  install_default_theme('toasted');
  install_admin_theme('toasted');
  
  // Do not show post info for pages.
  $theme_settings = variable_get('theme_settings', array());
  $theme_settings['toggle_node_info_page'] = FALSE;
  variable_set('theme_settings', $theme_settings);
  
  // Set logo and favicon.
  $toasted_settings = variable_get('theme_toasted_settings', array());
  $toasted_path = drupal_get_path('theme', 'toasted');
  $logo_path = $toasted_path . '/innovationnewsprofile/logo.png';
  $toasted_settings['default_logo'] = 0;
  $toasted_settings['logo_path'] = $logo_path;
  $favicon_path = $toasted_path . '/innovationnewsprofile/favicon.ico';
  $toasted_settings['default_favicon'] = 0;
  $toasted_settings['favicon_path'] = $favicon_path;
  variable_set('theme_toasted_settings', $toasted_settings);

  // Innovation News - set news types.
  $news_types = array('article' => 'article', 'readerstory' => 'readerstory');
  variable_set('innovationnews_news_types', $news_types);

  // XML to KML - specify data settings.
  $base_address = $GLOBALS['base_url'];
  $base_address .= (variable_get('clean_url', 0)) ? '/' : '/?q=';
  variable_set('xmltokml_file', $base_address . 'rss.xml');
  variable_set('xmltokml_title', 'channel-item-title');
  variable_set('xmltokml_author', 'channel-item-author');
  variable_set('xmltokml_body', 'channel-item-description');
  variable_set('xmltokml_location', 'channel-item-location');
  variable_set('xmltokml_image', 'channel-item-image');

  // Views - disable hover setting.
  variable_set('views_no_hover_links', '1');

  // CAPTCHA - require CAPTCHA for readerstory.
  db_query("INSERT INTO {captcha_points} (form_id, module, type) VALUES " .
           "('%s', '%s', '%s')", 'readerstory_node_form', 'captcha', 'Math');

  // Pathauto - define aliases for content types.
  variable_set('pathauto_node_article_pattern', 'articles/[title-raw]');
  variable_set('pathauto_node_readerstory_pattern', 'reader-stories/[title-raw]');
  variable_set('pathauto_node_image_pattern', 'images/[title-raw]');
  variable_set('pathauto_node_page_pattern', '[title-raw]');

  // Image - define size settings and maximum upload size.
  $image_sizes = array(
    '_original'  => array('width' => '', 'height' => '', 'label' => t('Original'), 'operation' => 'scale', 'link' => 1),
    'thumbnail'  => array('width' => 150, 'height' => 150, 'label' => t('Thumbnail'), 'operation' => 'scale', 'link' => 1),
    'preview'    => array('width' => 455, 'height' => 455, 'label' => t('Preview'), 'operation' => 'scale', 'link' => 1),
  );
  variable_set('image_sizes', $image_sizes);
  variable_set('image_max_upload_size', '2048');

  // Contemplate - set templates.
  $contemplate_article_teaser = '<?php' . "\r\n" . 'if($node->promote == 1 && drupal_is_front_page()) {' . "\r\n" . '  // Determine the filename of the attached image.' . "\r\n" . '  $pattern = \'/<div .*? class="image-attach-teaser"><a href="(.*?)"><img src="(.*?)" alt="(.*?)" title="(.*?)" (.*?) \\/><\\/a><\\/div>/\';' . "\r\n" . '  preg_match($pattern, $teaser, $matches);' . "\r\n" . '  $filename = $matches[2];' . "\r\n" . '' . "\r\n" . '  // Replace "thumnail" with "preview".' . "\r\n" . '  $filename_pattern = \'/(.*)(\\/.*?\\.)(.*?)\\.(.*?)$/\';' . "\r\n" . '  $filename_replacement = \'${1}${2}preview.$4\';' . "\r\n" . '  $preview_filename = preg_replace($filename_pattern, $filename_replacement, $filename);' . "\r\n" . '' . "\r\n" . '  // Display the "preview" version of the image.' . "\r\n" . '  $teaser = "<div style=\\"width: 455px;\\"><a href=\\"$matches[1]\\"><img src=\\"$preview_filename\\" alt=\\"$matches[3]\\" title=\\"$matches[4]\\" /></a></div> " . $teaser;' . "\r\n" . '}' . "\r\n" . '' . "\r\n" . '// Remove the original image from the teaser.' . "\r\n" . '$teaser = str_replace($node->content[\'image_attach\'][\'#children\'], \'\', $teaser);' . "\r\n\r\n" . 'print $teaser;' . "\r\n" . '?>';
  $contemplate_article_rss = '<?php' . "\r\n" . '// Determine the filename of the attached image.' . "\r\n" . '$pattern = \'/<div .*? class="image-attach-teaser"><a href="(.*?)"><img src="(.*?)" alt="(.*?)" title="(.*?)" (.*?) \/><\/a><\/div>/\';' . "\r\n\r\n" . 'preg_match($pattern, $node->content[\'image_attach\'][\'#children\'], $matches);' . "\r\n" . '$image = $matches[2];' . "\r\n\r\n" . '$xml_elements = array(' . "\r\n" . '  array(' . "\r\n" . '    \'key\' => \'author\',' . "\r\n" . '    \'value\' => $node->name,' . "\r\n" . '  ),' . "\r\n" . '  array(' . "\r\n" . '    \'key\' => \'location\',' . "\r\n" . '    \'value\' => $node->field_inews_location[0][\'safe\'],' . "\r\n" . '  ),' . "\r\n" . '  array(' . "\r\n" . '    \'key\' => \'image\',' . "\r\n" . '    \'value\' => $image,' . "\r\n" . '  ),' . "\r\n" . ');' . "\r\n\r\n" . 'print $teaser;' . "\r\n" . '?>';
  $contemplate_readerstory_teaser = '<?php' . "\r\n" . 'if (!empty($node->field_inews_readerstory_author[0][\'safe\'])) {' . "\r\n" . '  $node->name = $node->field_inews_readerstory_author[0][\'safe\'];' . "\r\n" . '}' . "\r\n\r\n" . 'print $teaser;' . "\r\n" . '?>';
  $contemplate_readerstory_body = '<?php' . "\r\n" . 'if (!empty($node->field_inews_readerstory_author[0][\'safe\'])) {' . "\r\n" . '  $node->name = $node->field_inews_readerstory_author[0][\'safe\'];' . "\r\n" . '}' . "\r\n\r\n" . 'print $body;' . "\r\n" . '?>';
  $contemplate_readerstory_rss = $contemplate_article_rss;
  db_query("INSERT INTO {contemplate} VALUES ('%s', '%s', '%s', '%s', '%s', %d)",
           'article', $contemplate_article_teaser, '', $contemplate_article_rss,
           '', 5);
  db_query("INSERT INTO {contemplate} VALUES ('%s', '%s', '%s', '%s', '%s', %d)",
           'readerstory', $contemplate_readerstory_teaser,
           $contemplate_readerstory_body, $contemplate_readerstory_rss, '', 7);
}

/**
 * Set the roles and permissions that will be used in this profile.
 */
function _innovationnewsprofile_set_permissions() {
  // Define new roles.
  db_query("INSERT INTO {role} (rid, name) VALUES(%d, '%s')", 3, 'administrator');
  db_query("INSERT INTO {role} (rid, name) VALUES(%d, '%s')", 4, 'writer');
  db_query("INSERT INTO {role} (rid, name) VALUES(%d, '%s')", 5, 'editor');
  db_query("INSERT INTO {role} (rid, name) VALUES(%d, '%s')", 6, 'photographer');
  db_query("INSERT INTO {role} (rid, name) VALUES(%d, '%s')", 7, 'manager');

  // Make user 1 an administrator.
  db_query("INSERT INTO {users_roles} VALUES (1, 3)");

  // Update "anonymous user" permissions.
  db_query("UPDATE {permission} SET perm = '%s' WHERE rid = %d",
           'edit field_inews_readerstory_author, access editionviewer, ' .
           'access content, search content, use advanced search, ' .
           'create readerstory content', 1);

  // Update "authenticated user" permissions.
  db_query("UPDATE {permission} SET perm = '%s' WHERE rid = %d",
           'access editionviewer, access content, search content, use ' .
           'advanced search, create readerstory content', 2);

  // Set administrator permissions (all permissions).
  $all_perm = 'administer blocks, use PHP for block visibility, administer ' .
              'CAPTCHA settings, skip CAPTCHA, administer templates, ' .
              'Use PHP input for field settings (dangerous - grant with care), ' .
              'edit field_inews_location, edit field_inews_readerstory_author, ' .
              'view field_inews_location, view field_inews_readerstory_author, ' .
              'access editionmanager, administer editionmanager settings, ' .
              'access editionviewer, access editionviewer XML data, administer editionviewer settings, access ' .
              'editnews, administer filters, create images, edit images, ' .
              'edit own images, view original images, administer images, administer core innovationnews settings, ' .
              'administer innovationnews settings, administer languages, ' .
              'translate interface, administer menu, access content, ' .
              'administer content types, administer nodes, create article ' .
              'content, create readerstory content, create page content, ' .
              'delete any article content, delete any readerstory content, ' .
              'delete any page content, delete own article content, delete ' .
              'own readerstory content, delete own page content, delete ' .
              'revisions, edit any article content, edit any page content, edit any readerstory ' .
              'content, edit own page content, edit own readerstory content, edit own article content, revert revisions, view ' .
              'revisions, administer url aliases, create url aliases, ' .
              'administer pathauto, notify of path changes, administer ' .
              'search, search content, use advanced search, access ' .
              'administration pages, access site reports,  administer ' .
              'actions, administer files, administer site configuration, ' .
              'select different theme, administer taxonomy, access user ' .
              'profiles, administer permissions, administer users, change ' .
              'own username, administer views, access all views, access xmltokml KML file, administer xmltokml settings, ' .
              'delete any images, delete own images, edit any images, attach images, administer image galleries';
  db_query("INSERT INTO {permission} (rid, perm, tid) VALUES (3, '%s', 0)",
           $all_perm);

  // Set "writer" permissions.
  db_query("INSERT INTO {permission} (rid, perm, tid) VALUES (4, '%s', 0)",
           'skip CAPTCHA, edit field_inews_location, create article content, ' .
           'attach images');

  // Set "editor" permissions.
  db_query("INSERT INTO {permission} (rid, perm, tid) VALUES (5, '%s', 0)",
           'skip CAPTCHA, edit field_inews_location, edit field_inews_readerstory_author, access editnews, administer nodes, edit any article content, ' .
           'edit any readerstory content, attach images');

  // Set "photographer" permissions.
  db_query("INSERT INTO {permission} (rid, perm, tid) VALUES (6, '%s', 0)",
           'skip CAPTCHA, create images');

  // Set "manager" permissions.
  db_query("INSERT INTO {permission} (rid, perm, tid) VALUES (7, '%s', 0)",
           'skip CAPTCHA, access editionmanager, access editionviewer, access editionviewer XML data');
}

/**
 * Set the content types for this profile.
 */
function _innovationnewsprofile_set_content_types() {
  // Define content types
  $article_description = st('An article. By default only writers can submit ' .
                            'articles.');
  $readerstory_description = st('A story written by a reader. By default, ' .
                                'any visitor can submit a reader story. ' .
                                'Like articles, reader stories are ' .
                                'unpublished by default.');
  $image_description = st('An image or photograph. By default, only a ' .
                          'photographer can submit an image.');
  $types = array (
    array(
      'type' => 'page',
      'name' => st('Page'),
      'module' => 'node',
      'description' => st('A static page.'),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
    ),
    array(
      'type' => 'article',
      'name' => st('Article'),
      'module' => 'node',
      'description' => $article_description,
      'custom' => TRUE,
      'locked' => FALSE,
    ),
    array(
      'type' => 'readerstory',
      'name' => st('Reader Story'),
      'module' => 'node',
      'description' => $readerstory_description,
      'custom' => TRUE,
      'locked' => FALSE,
    ),
    array(
      'type' => 'image',
      'name' => st('Image'),
      'module' => 'image',
      'description' => $image_description,
      'body_label' => st('Description'),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
    ),
  );

  // Save the node types.
  foreach ($types as $type) {
    $type = (object) _node_type_set_defaults($type);
    node_type_save($type);
  }

  // Disable all workflow options for article and readerstory.
  variable_set('node_options_article', array());
  variable_set('node_options_readerstory', array());

  // Disable "Promoted to front page" for images.
  variable_set('node_options_image', array('status'));

  // Allow images to be attached to articles.
  variable_set('image_attach_article', TRUE);
}

/**
 * Set vocabularies for this profile.
 */
function _innovationnewsprofile_set_vocabularies() {
  $topic_description = st('This vocabulary includes various possible topics ' .
                          'of news stories. While you are not required to ' .
                          'make use of this vocabulary, doing so improves ' .
                          'site organization and allows for easier ' .
                          'navigation.');

  // Create the "Topic" vocabulary
  $vocabulary_topic = array(
    'name' => st('Topic'),
    'description' => $topic_description,
    'multiple' => 0,
    'required' => 0,
    'hierarchy' => 0,
    'relations' => 0,
    'nodes' => array('article' => TRUE, 'readerstory' => TRUE),
  );
  taxonomy_save_vocabulary($vocabulary_topic);
  $vid_topic = $vocabulary_topic['vid'];

  // Define the terms of the topic vocabulary.
  $terms_topic = array(
    array(
      'name' => st('Business'),
      'vid' => $vid_topic,
      'weight' => 0,
      'parent' => 0,
    ),
    array(
      'name' => st('Entertainment'),
      'vid' => $vid_topic,
      'weight' => 0,
      'parent' => 0,
    ),
    array(
      'name' => st('Health'),
      'vid' => $vid_topic,
      'weight' => 0,
      'parent' => 0,
    ),
    array(
      'name' => st('Politics'),
      'vid' => $vid_topic,
      'weight' => 0,
      'parent' => 0,
    ),
    array(
      'name' => st('Science'),
      'vid' => $vid_topic,
      'weight' => 0,
      'parent' => 0,
    ),
    array(
      'name' => st('Sports'),
      'vid' => $vid_topic,
      'weight' => 0,
      'parent' => 0,
    ),
    array(
      'name' => st('Technology'),
      'vid' => $vid_topic,
      'weight' => 0,
      'parent' => 0,
    ),
    array(
      'name' => st('World'),
      'vid' => $vid_topic,
      'weight' => 0,
      'parent' => 0,
    ),
  );

  // Save the terms of the Topic vocabulary.
  foreach ($terms_topic as $term) {
    taxonomy_save_term($term);
  }
}

/**
 * Modify the block settings.
 */
function _innovationnewsprofile_modify_blocks() {
  global $theme_key;
  $theme_key = 'toasted';

  _block_rehash();  // Fill the DB with blocks created by modules.

  // Hide "Powered by Drupal".
  db_query("DELETE FROM {blocks} WHERE module = '%s' AND theme = '%s' " .
           "AND region = '%s'", 'system', 'toasted', 'footer');

  // Show "Navigation" on every page but the home page. Show only to
  // authenticated users.
  db_query("UPDATE {blocks} SET status = %d, region = '%s', pages = '%s' " .
           "WHERE module = '%s' AND delta = '%s' AND theme = '%s'",
           1, 'left', '<front>', 'user', '1', 'toasted');
  db_query("INSERT INTO {blocks_roles} VALUES('%s', '%s', %d)", 'user', '1', 2);

  // Move "Primary links" to the header.
  db_query("UPDATE {blocks} SET region = '%s', status = %d, weight = %d " .
           "WHERE theme = '%s' AND delta = '%s'", 'header', 1, 0,
           'toasted', 'primary-links');

  // Add the "RecentNotPromoted" manually, as Views does not create it during
  // the installation for some reason.
  db_query("UPDATE {blocks} SET status = %d, region = '%s', visibility = %d, pages = '%s' " .
           "WHERE delta = '%s' AND module = '%s' AND theme = '%s'",
           1, 'right', 1, '<front>', 'RecentNotPromoted-block_1', 'views', 'toasted');

  // Hide "User login".
  db_query("UPDATE {blocks} SET status = %d, region = '%s' " .
           "WHERE theme = '%s' AND bid = %d AND module = '%s'",
           0, NULL, 'toasted', 5, 'user');

  // Add "Log in".
  db_query("INSERT INTO {blocks} (module, delta, theme, status, weight, " .
           "region, custom, throttle, visibility, pages, title, cache) " .
           "VALUES ('%s', '%s', '%s', %d, %d, '%s', %d, %d, %d, '%s', '%s', %d)",
           'block', '5', 'toasted', 1, -10, 'footer', 0, 0, 0, NULL, NULL, -1);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '5', 1);
  db_query("INSERT INTO {boxes} VALUES (%d, '%s', '%s', %d)",
           5, '<p class="link"><?php print l(\'Log in\', \'user\'); ?></p>', 'Log in', 3);

  // Add "Control Center".
  db_query("INSERT INTO {blocks} (module, delta, theme, status, weight, " .
           "region, custom, throttle, visibility, pages, title, cache) " .
           "VALUES ('%s', '%s', '%s', %d, %d, '%s', %d, %d, %d, '%s', '%s', %d)",
           'block', '6', 'toasted', 1, -9, 'footer', 0, 0, 0, NULL, NULL, -1);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '6', 3);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '6', 4);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '6', 5);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '6', 6);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '6', 7);
  db_query("INSERT INTO {boxes} VALUES (%d, '%s', '%s', %d)",
           6, '<p class="link"><?php print l(\'Control Center\', \'control-center\'); ?></p>',
           'Control Center', 3);

  // Add "Writer Panel".
  $writer_content = '<?php print l(\'Write an Article\', \'node/add/article\'); ?>';
  db_query("INSERT INTO {blocks} (module, delta, theme, status, weight, " .
           "region, custom, throttle, visibility, pages, title, cache) " .
           "VALUES ('%s', '%s', '%s', %d, %d, '%s', %d, %d, %d, '%s', '%s', %d)",
           'block', '3', 'toasted', 1, -8, 'left', 0, 0, 0, '<front>',
           'Writer Panel', -1);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '3', 3);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '3', 4);
  db_query("INSERT INTO {boxes} VALUES (%d, '%s', '%s', %d)",
           3, $writer_content, 'Writer Panel', 3);

  // Add "Photographer Panel".
  $photographer_content = '<?php print l(\'Upload an Image\', \'node/add/image\'); ?>';
  db_query("INSERT INTO {blocks} (module, delta, theme, status, weight, " .
           "region, custom, throttle, visibility, pages, title, cache) " .
           "VALUES ('%s', '%s', '%s', %d, %d, '%s', %d, %d, %d, '%s', '%s', %d)",
           'block', '4', 'toasted', 1, -7, 'left', 0, 0, 0, '<front>',
           'Photographer Panel', -1);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '4', 3);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '4', 6);
  db_query("INSERT INTO {boxes} VALUES (%d, '%s', '%s', %d)",
           4, $photographer_content, 'Photographer Panel', 3);

  // Add "Editor Panel".
  $editor_content = '<?php print l(\'Edit News\', \'editnews\'); ?>';
  db_query("INSERT INTO {blocks} (module, delta, theme, status, weight, " .
           "region, custom, throttle, visibility, pages, title, cache) " .
           "VALUES ('%s', '%s', '%s', %d, %d, '%s', %d, %d, %d, '%s', '%s', %d)",
           'block', '2', 'toasted', 1, -6, 'left', 0, 0, 0, '<front>',
           'Editor Panel', -1);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '2', 3);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '2', 5);
  db_query("INSERT INTO {boxes} VALUES (%d, '%s', '%s', %d)",
           2, $editor_content, 'Editor Panel', 3);

  // Add "Manager Panel".
  $manager_content = '<?php ' . "\r\n" .
                     'print l(\'Manage Editions\', \'editionmanager\');' . "\r\n" .
                     'print l(\'View Editions\', \'editionviewer\');' . "\r\n" . '?>';
  db_query("INSERT INTO {blocks} (module, delta, theme, status, weight, " .
           "region, custom, throttle, visibility, pages, title, cache) " .
           "VALUES ('%s', '%s', '%s', %d, %d, '%s', %d, %d, %d, '%s', '%s', %d)",
           'block', '1', 'toasted', 1, -5, 'left', 0, 0, 0, '<front>',
           'Manager Panel', -1);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '1', 3);
  db_query("INSERT INTO {blocks_roles} VALUES ('%s', '%s', %d)",
           'block', '1', 7);
  db_query("INSERT INTO {boxes} VALUES (%d, '%s', '%s', %d)",
           1, $manager_content, 'Manager Panel', 3);
}

/**
 * Save nodes which will be used in the profile.
 */
function _innovationnewsprofile_save_nodes() {
  // Determine the username of user 1.
  $user_1 = user_load(array('uid' => 1));
  $user_1_name = $user_1->name;

  // Save the "Control Center" page.
  $control_center_body = control_center_content();
  $control_center = array (
    'type' => 'page',
    'language' => 'en',
    'uid' => 1,
    'status' => 1,
    'comment' => 0,
    'promote' => 0,
    'moderate' => 0,
    'sticky' => 0,
    'tnid' => 0,
    'translate' => 0,
    'vid' => 1,
    'revision_uid' => 1,
    'title' => st('Control Center'),
    'body' => $control_center_body,
    'teaser' => node_teaser($control_center_body),
    'format' => 3,
    'name' => $user_1_name,
  );
  $control_center = (object) $control_center;
  node_save($control_center);

}

/**
 * Add and delete items from the menus.
 */
function _innovationnewsprofile_modify_menus() {
  // Add items to the Primary Links menu.
  $menu_editionviewer = array(
    'menu_name' => 'primary-links',
    'link_title' => st('View Editions'),
    'link_path' => 'editionviewer',
    'weight' => 1,
  );
  $menu_write_readerstory = array(
    'menu_name' => 'primary-links',
    'link_title' => st('Contribute'),
    'link_path' => 'node/add/readerstory',
    'weight' => 2,
  );
  menu_link_save($menu_editionviewer);
  menu_link_save($menu_write_readerstory);

  // Add a link to each taxonomy term to the Primary Links menu.
  $menu_taxonomy = array(
    array(
      'menu_name' => 'primary-links',
      'link_title' => st('Business'),
      'link_path' => 'taxonomy/term/1',
    ),
    array(
      'menu_name' => 'primary-links',
      'link_title' => st('Entertainment'),
      'link_path' => 'taxonomy/term/2',
    ),
    array(
      'menu_name' => 'primary-links',
      'link_title' => st('Health'),
      'link_path' => 'taxonomy/term/3',
    ),
    array(
      'menu_name' => 'primary-links',
      'link_title' => st('Politics'),
      'link_path' => 'taxonomy/term/4',
    ),
    array(
      'menu_name' => 'primary-links',
      'link_title' => st('Science'),
      'link_path' => 'taxonomy/term/5',
    ),
    array(
      'menu_name' => 'primary-links',
      'link_title' => st('Sports'),
      'link_path' => 'taxonomy/term/6',
    ),
    array(
      'menu_name' => 'primary-links',
      'link_title' => st('Technology'),
      'link_path' => 'taxonomy/term/7',
    ),
    array(
      'menu_name' => 'primary-links',
      'link_title' => st('World'),
      'link_path' => 'taxonomy/term/8',
    ),
  );
  foreach ($menu_taxonomy as $item) {
    menu_link_save($item);
  }
}

/**
 * Sets the Views for this profile.
 *
 * Be aware that this function is extraordinarily ugly. It also exceeds the 80
 * character wordwrap standard...just by a little bit. :)
 */
function _innovationnewsprofile_set_views() {
  db_query("INSERT INTO {views_view} (vid, name, description, tag, view_php, base_table, is_cacheable) " .
           "VALUES (%d, '%s', '%s', '%s', %b, '%s', %d)",
           1, 'RecentPromoted', 'The most recently added stories which have been promoted to the front page.', '', '', 'node', 0);
  db_query("INSERT INTO {views_view} (vid, name, description, tag, view_php, base_table, is_cacheable) " .
           "VALUES (%d, '%s', '%s', '%s', %b, '%s', %d)",
           2, 'RecentNotPromoted', 'The most recently added stories which have not been promoted to the front page. ', '', '', 'node', 0);
  db_query("INSERT INTO {views_view} (vid, name, description, tag, view_php, base_table, is_cacheable) " .
           "VALUES (%d, '%s', '%s', '%s', %b, '%s', %d)",
           3, 'RSS', 'The main RSS feed of the site.', '', '', 'node', 0);

  // Use the site name as the title of the RSS feed.
  $rss_default = 'a:5:{s:10:"row_plugin";s:4:"node";s:11:"row_options";a:2:{s:6:"teaser";i:1;s:5:"links";i:0;}s:7:"filters";a:2:{s:6:"status";a:9:{s:8:"operator";s:1:"=";s:5:"value";i:1;s:5:"group";s:1:"0";s:7:"exposed";b:0;s:6:"expose";a:2:{s:8:"operator";b:0;s:5:"label";s:0:"";}s:2:"id";s:6:"status";s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";}s:4:"type";a:9:{s:8:"operator";s:2:"in";s:5:"value";a:2:{s:7:"article";s:7:"article";s:11:"readerstory";s:11:"readerstory";}s:5:"group";s:1:"0";s:7:"exposed";b:0;s:6:"expose";a:2:{s:8:"operator";b:0;s:5:"label";s:0:"";}s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";}}s:5:"sorts";a:1:{s:7:"created";a:6:{s:5:"order";s:4:"DESC";s:11:"granularity";s:6:"second";s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";}}s:5:"title";s:0:"";}';
  $rss_default_array = unserialize($rss_default);
  $rss_default_array['title'] = variable_get('site_name', 'Recent News');
  $rss_default = serialize($rss_default_array);

  db_query("INSERT INTO {views_display} (vid, id, display_title, display_plugin, position, display_options) " .
           "VALUES (%d, '%s', '%s', '%s', %d, %b)",
           1, 'default', 'Defaults', 'default', 1, 'a:8:{s:10:"row_plugin";s:4:"node";s:11:"row_options";a:2:{s:6:"teaser";i:1;s:5:"links";i:0;}s:14:"items_per_page";i:2;s:6:"offset";i:0;s:5:"empty";s:62:"No published stories have been promoted to the front page yet.";s:12:"empty_format";s:1:"1";s:5:"sorts";a:2:{s:6:"sticky";a:5:{s:5:"order";s:4:"DESC";s:2:"id";s:6:"sticky";s:5:"table";s:4:"node";s:5:"field";s:6:"sticky";s:12:"relationship";s:4:"none";}s:7:"created";a:6:{s:5:"order";s:4:"DESC";s:11:"granularity";s:6:"second";s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";}}s:7:"filters";a:3:{s:7:"promote";a:9:{s:8:"operator";s:1:"=";s:5:"value";i:1;s:5:"group";s:1:"0";s:7:"exposed";b:0;s:6:"expose";a:2:{s:8:"operator";b:0;s:5:"label";s:0:"";}s:2:"id";s:7:"promote";s:5:"table";s:4:"node";s:5:"field";s:7:"promote";s:12:"relationship";s:4:"none";}s:6:"status";a:9:{s:8:"operator";s:1:"=";s:5:"value";i:1;s:5:"group";s:1:"0";s:7:"exposed";b:0;s:6:"expose";a:2:{s:8:"operator";b:0;s:5:"label";s:0:"";}s:2:"id";s:6:"status";s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";}s:4:"type";a:9:{s:8:"operator";s:2:"in";s:5:"value";a:2:{s:7:"article";s:7:"article";s:11:"readerstory";s:11:"readerstory";}s:5:"group";s:1:"0";s:7:"exposed";b:0;s:6:"expose";a:2:{s:8:"operator";b:0;s:5:"label";s:0:"";}s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";}}}');
  db_query("INSERT INTO {views_display} (vid, id, display_title, display_plugin, position, display_options) " .
           "VALUES (%d, '%s', '%s', '%s', %d, %b)",
           2, 'default', 'Defaults', 'default', 1, 'a:8:{s:10:"row_plugin";s:4:"node";s:11:"row_options";a:2:{s:6:"teaser";i:1;s:5:"links";i:0;}s:14:"items_per_page";i:5;s:6:"offset";i:0;s:5:"empty";s:80:"No stories have been published yet, or all published stories have been promoted.";s:12:"empty_format";s:1:"1";s:5:"sorts";a:2:{s:6:"sticky";a:5:{s:5:"order";s:4:"DESC";s:2:"id";s:6:"sticky";s:5:"table";s:4:"node";s:5:"field";s:6:"sticky";s:12:"relationship";s:4:"none";}s:7:"created";a:6:{s:5:"order";s:4:"DESC";s:11:"granularity";s:6:"second";s:2:"id";s:7:"created";s:5:"table";s:4:"node";s:5:"field";s:7:"created";s:12:"relationship";s:4:"none";}}s:7:"filters";a:3:{s:6:"status";a:9:{s:8:"operator";s:1:"=";s:5:"value";i:1;s:5:"group";s:1:"0";s:7:"exposed";b:0;s:6:"expose";a:2:{s:8:"operator";b:0;s:5:"label";s:0:"";}s:2:"id";s:6:"status";s:5:"table";s:4:"node";s:5:"field";s:6:"status";s:12:"relationship";s:4:"none";}s:4:"type";a:9:{s:8:"operator";s:2:"in";s:5:"value";a:2:{s:7:"article";s:7:"article";s:11:"readerstory";s:11:"readerstory";}s:5:"group";s:1:"0";s:7:"exposed";b:0;s:6:"expose";a:2:{s:8:"operator";b:0;s:5:"label";s:0:"";}s:2:"id";s:4:"type";s:5:"table";s:4:"node";s:5:"field";s:4:"type";s:12:"relationship";s:4:"none";}s:7:"promote";a:9:{s:8:"operator";s:1:"=";s:5:"value";i:0;s:5:"group";s:1:"0";s:7:"exposed";b:0;s:6:"expose";a:2:{s:8:"operator";b:0;s:5:"label";s:0:"";}s:2:"id";s:7:"promote";s:5:"table";s:4:"node";s:5:"field";s:7:"promote";s:12:"relationship";s:4:"none";}}}');
  db_query("INSERT INTO {views_display} (vid, id, display_title, display_plugin, position, display_options) " .
           "VALUES (%d, '%s', '%s', '%s', %d, %b)",
           3, 'feed_1', 'Feed', 'feed', 2, 'a:3:{s:4:"path";s:7:"rss.xml";s:10:"row_plugin";s:8:"node_rss";s:11:"row_options";a:1:{s:11:"item_length";s:7:"default";}}');
  db_query("INSERT INTO {views_display} (vid, id, display_title, display_plugin, position, display_options) " .
           "VALUES (%d, '%s', '%s', '%s', %d, %b)",
           3, 'default', 'Defaults', 'default', 1, $rss_default);
  db_query("INSERT INTO {views_display} (vid, id, display_title, display_plugin, position, display_options) " .
           "VALUES (%d, '%s', '%s', '%s', %d, %b)",
           1, 'page_1', 'Page', 'page', 2, 'a:1:{s:4:"path";s:4:"home";}');
  db_query("INSERT INTO {views_display} (vid, id, display_title, display_plugin, position, display_options) " .
           "VALUES (%d, '%s', '%s', '%s', %d, %b)",
           2, 'block_1', 'Block', 'block', 2, 'a:0:{}');
}

function _innovationnewsprofile_set_cck_fields() {
  $article_location = array (
    'field_name' => 'field_inews_location',
    'type_name' => 'article',
    'display_settings' => 
    array (
      'label' => 
      array (
        'format' => 'hidden',
      ),
      'teaser' => 
      array (
        'format' => 'hidden',
      ),
      'full' => 
      array (
        'format' => 'hidden',
      ),
      4 => 
      array (
        'format' => 'default',
      ),
      2 => 
      array (
        'format' => 'default',
      ),
      3 => 
      array (
        'format' => 'default',
      ),
    ),
    'widget_active' => '1',
    'type' => 'text',
    'required' => '0',
    'multiple' => '0',
    'db_storage' => '1',
    'module' => 'text',
    'active' => '1',
    'locked' => '0',
    'columns' => 
    array (
      'value' => 
      array (
        'type' => 'text',
        'size' => 'big',
        'not null' => false,
        'sortable' => true,
      ),
    ),
    'text_processing' => '0',
    'max_length' => '',
  'allowed_values' => '40.689232, -74.044649|Statue of Liberty
39.948941202874806, -75.14997124671936|Independence Hall',
    'allowed_values_php' => '',
    'widget' => 
    array (
      'default_value' => 
      array (
        0 => 
        array (
          'value' => '',
          '_error_element' => 'default_value_widget][field_inews_location][value',
        ),
      ),
      'default_value_php' => NULL,
      'label' => 'Location',
      'weight' => '-3',
      'description' => 'The location which this story relates to.',
      'type' => 'optionwidgets_select',
      'module' => 'optionwidgets',
    ),
  );

  $readerstory_author = array (
    'field_name' => 'field_inews_readerstory_author',
    'type_name' => 'readerstory',
    'display_settings' => 
    array (
      'label' => 
      array (
        'format' => 'hidden',
      ),
      'teaser' => 
      array (
        'format' => 'hidden',
      ),
      'full' => 
      array (
        'format' => 'hidden',
      ),
      4 => 
      array (
        'format' => 'default',
      ),
      2 => 
      array (
        'format' => 'default',
      ),
      3 => 
      array (
        'format' => 'default',
      ),
    ),
    'widget_active' => '1',
    'type' => 'text',
    'required' => '0',
    'multiple' => '0',
    'db_storage' => '1',
    'module' => 'text',
    'active' => '1',
    'locked' => '0',
    'columns' => 
    array (
      'value' => 
      array (
        'type' => 'text',
        'size' => 'big',
        'not null' => false,
        'sortable' => true,
      ),
    ),
    'text_processing' => '0',
    'max_length' => '',
    'allowed_values' => '',
    'allowed_values_php' => '',
    'widget' => 
    array (
      'rows' => 5,
      'size' => '60',
      'default_value' => 
      array (
        0 => 
        array (
          'value' => '',
          '_error_element' => 'default_value_widget][field_inews_readerstory_author][0][value',
        ),
      ),
      'default_value_php' => NULL,
      'label' => 'Author',
      'weight' => '-4',
      'description' => 'Enter your name as you would like it to appear with your story.',
      'type' => 'text_textfield',
      'module' => 'text',
    ),
  );

  _innovationnewsprofile_install_cck($article_location, 'article');
  _innovationnewsprofile_install_cck($readerstory_author, 'readerstory');
}

/**
 * Import CCK settings.
 *
 * @param $field
 *   The data provided by var_export(content_fields(fieldname, content_type)).
 * @param $content_type
 *   The content type that this field should be added to.
 */
function _innovationnewsprofile_install_cck($field, $content_type) {
  module_load_include('inc', 'content', 'includes/content.crud');

  $field['type_name'] = $content_type;
  content_field_instance_create($field);
}

/**
 * Build the content of the Control Center page.
 *
 * @return
 *   The content of the Control Center page.
 */
function control_center_content() {
  $output = '<?php
global $user;

if ($user->uid == 1) {
  print \'<p>Welcome to Innovation News. With Innovation News, you will be able to run your own cross-media newspaper.</p>
<p>As the individual who installed Innovation News, you are an administrator. You are able to create content, publish news stories, and place news stories into editions. You also have full control over the website.</p>
<strong>Using Innovation News</strong>
<p>All the major tools which you need to run your Innovation News website are accessible via the Panels to the left. If you are the only individual who will be working on your website, you are ready to begin. If you wish to run your website in a team environment, you can create team members using the guide directly below.</p>\';
}
if (in_array(\'administrator\', array_values($user->roles))) {
  print \'<strong>Setting Up Your Innovation News Team</strong>
<p>If plan to use Innovation News in a team environment, you may wish to create more users and assign specific roles to them. Each role grants a user the ability to access different Panels and perform different tasks.</p>
<p>Navigate to \' . l(\'Administer > User Management > Users > Add User\', \'admin/user/user/create\') . \'. Fill in all necessary information for each user you wish to create. There are five different roles to which a user can be assigned.:<br />
administrator - administer almost any aspect of the website<br />
photographer - upload photographs and other images which writers can later attach to news articles<br />
writer - write articles and attach images to them<br />
editor - edit and publish news<br />
manager - place news into editions</p>
<strong>Displaying News</strong>
<p>By default, all published news stories are displayed on the front page at some time. The two most recent stories which have been marked "Promoted to front page" will be displayed prominently on the left portion of the front page. The five most recent stories which have not been promoted will be displayed on the right portion of the front page.</p>
<p>In addition, any stories which have been assigned a "Topic" can be accessed via the topic links near the top of the website.</p>
<strong>Using Editions</strong>
<p>Using the pre-installed Innovation News module, you (and any managers) will be able to place news stories into editions. Editions serve the same purpose as editions of newspapers or editions of magazines - to group several stories together for one cohesive release.</p>
<p>To place news stories into editions, use the "Manage Editions" link in the Manager Panel. Once news stories have been placed into editions, they can be viewed via the "View Editions" link in the Manager Panel and near the top of the website. Note that site visitors will also be able to access the "View Editions" page. For more information on working with editions, see the "Managing Editions" guide below.</p>
<p>To expand the number of editions, visit the \' . l(\'Edition Manager settings page\', \'admin/settings/editionmanager\') . \'.</p>
<p>To control how editions are displayed, visit the \' . l(\'Edition Viewer settings page\', \'admin/settings/editionviewer\') . \'.</p>
<strong>Displaying News in Google Earth&#153;</strong>
<p>Innovation News is able to convert the site\\\'s RSS feed into a KML file. This KML file can be loaded into Google Earth&#153; to display news geographically.</p>
<p>Whenever you or a writer writes an article, you will have the option of specifying a "Location". This location specifies which area of the world the news relates to. For example, a news story about a renovation of the Statue of Liberty might use "Statue of Liberty" as the location.</p>
<p>Two sample locations have been provided for you. To build the list of possible locations, visit the \' . l(\'Location field settings page\', \'admin/content/node-type/article/fields/field_inews_location\') . \'. In the "Allowed values" text area, enter locations in the following format:<br />
<em>latitude, longitude|Location Name</em></p>
<p>Latitude and longitude coordinates can be determined using \' . l(\'Google Maps\', \'http://maps.google.com/\') . \'&#153; and \' . l(\'this guide\', \'http://lifehacker.com/software/google-maps/how-to-find-latitude-and-longitude-267361.php\') . \'.</p>
<p>Once you have published news stories with locations, click the \' . l(\'KML Output\', \'xmltokml.kml\') . \' link to the left. Save the KML file and open it in Google Earth&#153; to view your news stories by location.</p>
<strong>Reader Stories</strong>
<p>By default, Innovation News allows visitors to submit their own news stories via the "Contribute" link near the top of the website. Think of it as \' . l(\'Wikipedia\', \'http://www.wikipedia.org/\') . \' for your site\\\'s news. The submitted stories may be opinion pieces, reactions to current events, or anything else visitors feel like contributing.</p>
<p>Just like articles, these stories are unpublished by default. They follow a workflow identical to that of writer-submitted articles. Editors will be able to publish them and managers will be able to place them into editions. Once published they will be displayed on the front page, added to the RSS feed, and used in the output KML file.</p>
<p>If you would like to disallow users from submitting these types of stories, navigate to \' . l(\'Administer > Content Management > Content Types\', \'admin/content/types\') . \' and click "delete" in the Reader Story row. If any Reader Stories had been submitted previously, you may wish to delete them manually by navigating to \' . l(\'Administer > Content\', \'admin/content/node\') . \'.</p>\';
  }
  if (in_array(\'writer\', array_values($user->roles)) || in_array(\'administrator\', array_values($user->roles))) {
    print \'<strong>Writing Articles</strong>
<p>To write an article, click \' . l(\'Write an Article\', \'node/add/article\') . \' in the Writer Panel. Fill in a title, a body, and any other information which is required.</p>
<p>If your article fits into any of the available topics, select that topic from "Topic" selection box. If your article relates to any particular location, select that location from the "Location" selection box. If you would like to attach an image to your story, expand the "Attached Images" form and select an existing image.</p>
<p>If you would like to preview your article before you save it, click the "Preview" button at the bottom of the page. Once you are satisfied, click the "Save" button. Your article will be reviewed by the editors before it becomes available on the website.</p>\';
  }
  if (in_array(\'photographer\', array_values($user->roles)) || in_array(\'administrator\', array_values($user->roles))) {
    print \'<strong>Uploading Photographs</strong>
<p>To upload a photograph or any type of image, click \' . l(\'Upload an Image\', \'node/add/image\') . \' in the Photographer Panel.</p>
<p>Choose a straightforward but descriptive title for your image. Writers will use these titles when determining which images to attach to their articles. Using the "Browse" form, choose an image from your hard drive. If necessary, provide a description of the image.</p>
<p>If you would like to preview your image before you save it, click the "Preview" button at the bottom of the page. Once you are satisfied, click the "Save" button. Your image will automatically be available to writers for use in articles.</p>\';
  }
  if (in_array(\'editor\', array_values($user->roles)) || in_array(\'administrator\', array_values($user->roles))) {
    print \'<strong>Editing News</strong>
<p>To edit news, click \' . l(\'Edit News\', \'editnews\') . \' in the Editor Panel.</p>
<p>By default, only unpublished news will be displayed. To change your settings, modify the filter and click "View". For each story that matches the filter, you will see a teaser, basic story information, and an "Edit" link. To edit, publish, or delete the story, click the "Edit" link.</p>
<p>After clicking the "Edit" link, you will be able to edit any aspect of the story. When you are satisfied with the news story, expand the "Publishing options" form and check "Publish". All published stories are listed on the front page, but if you would like the story to be displayed more prominently on the left side of the front page, additionally check "Promoted to front page". If you would like this story to always be listed on above other stories regardless of post date, additionally check "Sticky at top of lists".</p>
<p>If you would like to preview the story before you save it, click the "Preview" button at the bottom of the page. Once you are satisfied, click the "Save" button.</p>
<p>If you would rather delete the news story completely, click the "Delete" button at the bottom of the page. Be aware that this cannot be undone.</p>\';
  }
  if (in_array(\'manager\', array_values($user->roles)) || in_array(\'administrator\', array_values($user->roles))) {
    print \'<strong>Managing Editions</strong>
<p>Editions serve the same purpose as editions of newspapers or editions of magazines - to group several stories together for one cohesive release.</p>
<p>To place news into editions, click \' . l(\'Manage Editions\', \'editionmanager\') . \' in the Manager Panel.</p>
<p>The Edition Manager only displays news which is published. By default, only news which does not belong to an edition will be displayed. To change your settings, modify the filter and click "View". For each story that matches the filter, you will see a teaser, basic story information, and an "Edition" selection box.</p>
<p>To place a story into an edition, modify that story\\\'s "Edition" select box. If you would like to remove a story from an edition, select "- None -" for that story. When you are satisfied with your changes, click the "Save" button at the bottom of the page. The editions will be applied immediately.</p>
<p>To confirm that the editions are as you intended, click \' . l(\'View Editions\', \'editionviewer\') . \' in the Manager Panel.</p>\';
  }
?>';

  return $output;
}
